@@ -330,7 +330,7 @@ while (time < $s) {
     while( time < $g) {
         my $x  = int(rand(600 * $xm));
         my $y  = int(rand(900 * $ym));
-        my $h  = 4 + ($YY < 128) ? rand(20) : int(rand(300 * $ym));
+        my $h  = ($YY < 128) ? (6+rand(60)) : (8+int(rand(300 * $ym)));
         my $ws = ($XX < 256) ? rand(2) : rand(4);
     
         my $b = $F->ttf_print(
@@ -436,7 +436,7 @@ while (time < $s) {
             'y'      => 0,
             'width'  => rand($XX),
             'height' => rand($YY),
-            'file'   => 'examples/testpattern.jpg'
+            'file'   => 'images/testpattern.jpg'
         }
     );
     $F->blit_write($image);
@@ -447,7 +447,7 @@ my $image = $F->load_image(
         'y'      => 0,
         'width'  => $XX,
         'height' => $YY,
-        'file'   => 'examples/testpattern.jpg'
+        'file'   => 'images/testpattern.jpg'
     }
 );
 $F->blit_write($image);
@@ -457,17 +457,17 @@ print_it($F, 'Testing Image blitting');
 
 $image = $F->load_image(
     {
-        'x'    => 0,
-          'y'    => 0,
-          'width' => min(640,$XX/2),
-          'height' => min(405,$YY/2),
-          'file' => 'examples/RWBY_Faces.png'
+        'x'      => 0,
+        'y'      => 0,
+        'width'  => min(640,$XX/2),
+        'height' => min(405,$YY/2),
+        'file'   => 'images/RWBY_Faces.png'
     }
 );
 $s = time + $factor;
 while (time < $s) {
-    $image->{'x'} = rand($XX - $image->{'width'});
-    $image->{'y'} = rand($YY - $image->{'height'});
+    $image->{'x'} = abs(rand($XX - $image->{'width'}));
+    $image->{'y'} = abs(rand($YY - $image->{'height'}));
     $F->blit_write($image);
 }
 
